@@ -23,10 +23,10 @@ else:
 
 __all__ = (
     "HumanLoopOutputTypeDef",
+    "HumanLoopSummaryTypeDef",
     "DescribeHumanLoopResponseTypeDef",
     "HumanLoopDataAttributesTypeDef",
     "HumanLoopInputTypeDef",
-    "HumanLoopSummaryTypeDef",
     "ListHumanLoopsResponseTypeDef",
     "PaginatorConfigTypeDef",
     "StartHumanLoopResponseTypeDef",
@@ -34,6 +34,18 @@ __all__ = (
 
 HumanLoopOutputTypeDef = TypedDict("HumanLoopOutputTypeDef", {"OutputS3Uri": str})
 
+HumanLoopSummaryTypeDef = TypedDict(
+    "HumanLoopSummaryTypeDef",
+    {
+        "HumanLoopName": str,
+        "HumanLoopStatus": Literal["InProgress", "Failed", "Completed", "Stopped", "Stopping"],
+        "CreationTime": datetime,
+        "FailureReason": str,
+        "FlowDefinitionArn": str,
+    },
+    total=False,
+)
+
 _RequiredDescribeHumanLoopResponseTypeDef = TypedDict(
     "_RequiredDescribeHumanLoopResponseTypeDef",
     {
@@ -46,7 +58,7 @@ _RequiredDescribeHumanLoopResponseTypeDef = TypedDict(
 )
 _OptionalDescribeHumanLoopResponseTypeDef = TypedDict(
     "_OptionalDescribeHumanLoopResponseTypeDef",
-    {"FailureReason": str, "FailureCode": str, "HumanLoopOutput": HumanLoopOutputTypeDef},
+    {"FailureReason": str, "FailureCode": str, "HumanLoopOutput": "HumanLoopOutputTypeDef"},
     total=False,
 )
 
@@ -68,20 +80,9 @@ HumanLoopDataAttributesTypeDef = TypedDict(
 
 HumanLoopInputTypeDef = TypedDict("HumanLoopInputTypeDef", {"InputContent": str})
 
-HumanLoopSummaryTypeDef = TypedDict(
-    "HumanLoopSummaryTypeDef",
-    {
-        "HumanLoopName": str,
-        "HumanLoopStatus": Literal["InProgress", "Failed", "Completed", "Stopped", "Stopping"],
-        "CreationTime": datetime,
-        "FailureReason": str,
-        "FlowDefinitionArn": str,
-    },
-    total=False,
-)
-
 _RequiredListHumanLoopsResponseTypeDef = TypedDict(
-    "_RequiredListHumanLoopsResponseTypeDef", {"HumanLoopSummaries": List[HumanLoopSummaryTypeDef]}
+    "_RequiredListHumanLoopsResponseTypeDef",
+    {"HumanLoopSummaries": List["HumanLoopSummaryTypeDef"]},
 )
 _OptionalListHumanLoopsResponseTypeDef = TypedDict(
     "_OptionalListHumanLoopsResponseTypeDef", {"NextToken": str}, total=False
